<?php
defined( 'ABSPATH' ) || exit;

class FDP_Frontend_Singles_Page extends Eos_Fdp_Matrix_Page {
  public $is_home;
  public $default_language;
  public $home_url;
  public $plugins_table;
  public $posts;
  public $posts_per_page;
  public $show_on_front;
  public $post_type;
  public $active_label;
  public $important_pages;
  public $is_relevant_pages;
  public $fdp_is_single_post;
  public $single_post_id = false;
  public $page_on_front;
  public $overridable;
  public $title;
  public $post_types_matrix;
  public $post_types_matrix_pt;

  public function before_section( $page_slug ){
  	wp_nonce_field( 'eos_dp_key', 'eos_dp_key' );
    $this->default_language = eos_dp_default_language();
  	$this->home_url = get_option( 'home' );
  	$this->plugins_table = eos_dp_plugins_table();
    $default_posts_per_page = !wp_is_mobile() ? 30 : 15;
  	$this->posts_per_page = isset( $_GET['posts_per_page'] ) && absint( $_GET['posts_per_page'] ) > 0 ? esc_attr( $_GET['posts_per_page'] ) : $default_posts_per_page;
  	$this->post_type = isset( $_GET['eos_dp_post_type'] ) ? esc_attr( $_GET['eos_dp_post_type'] ) : 'page';
    $this->title = isset( $_GET['eos_dp_relevant_pages'] ) && 'true' === $_GET['eos_dp_relevant_pages'] ? __( 'Relevant pages','eos-dp' ) : $this->active_label;
    $this->dataset = ' data-post_type="'.esc_attr( $this->post_type ).'"';
    $this->title = isset( $_GET['eos_dp_home'] ) && 'true' === $_GET['eos_dp_home'] ? __( 'Homepage','eos-dp' ) : $this->title;
  	$labsObj = get_post_type_object( $this->post_type );
  	if( isset( $labsObj->labels ) ){
  		$labs = $labsObj->labels;
  		$this->active_label = isset( $labs->name ) ? $labs->name : __( 'posts','eos-dp' );
  	}
  	$eos_dp_need_custom_url = eos_dp_get_option( 'eos_dp_need_custom_url' );
  	$this->post_types_matrix = eos_dp_get_option( 'eos_post_types_plugins' );
  	$this->post_types_matrix_pt = isset( $this->post_types_matrix[$this->post_type] ) ? $this->post_types_matrix[$this->post_type] : array();
  	$post_types_plugins_pt = isset( $this->plugins_table[$this->post_type] ) ? $this->plugins_table[$this->post_type] : false;
  	$this->overridable = $post_types_plugins_pt && isset( $post_types_plugins_pt[0] ) ? $post_types_plugins_pt[0] : false;
  	$current_labels_name = '';
  	$need_custom_url = array();
  	$ofs = isset( $_GET['eos_page'] ) && absint( $_GET['eos_page'] ) > 0 ? ( absint( $_GET['eos_page'] ) - 1 ) * $this->posts_per_page : 0;
  	$args = array( 'post_type' => $this->post_type,'post_status' => 'any','posts_per_page' => $this->posts_per_page,'offset' => $ofs );
  	$args['orderby'] = isset( $_GET['orderby'] ) ? esc_attr( $_GET['orderby'] ) : 'title';
  	$args['order'] = isset( $_GET['order'] ) ? esc_attr( $_GET['order'] ) : 'ASC';
  	if( isset( $_GET['lang'] ) ){
  		$args['suppress_filters'] = false;
  	}
  	$this->is_hierarchical = is_post_type_hierarchical( $this->post_type );
  	if( isset( $_GET['eos_dp_post_in'] ) && ''  !== $_GET['eos_dp_post_in'] ){
  		$args['post__in'] = explode( '-',esc_attr( $_GET['eos_dp_post_in'] ) );
  	}
  	if( isset( $_GET['eos_post_title'] ) ){
  		?><h2><?php printf( __( 'Results for %s','eos-dp' ),esc_html( $_GET['eos_post_title'] ) ); ?></h2><?php
  		$args['s'] = esc_attr( urldecode( $_GET['eos_post_title'] ) );
  	}
  	if( isset( $_GET['eos_cat'] ) ){
  		$cat = get_term( (int) $_GET['eos_cat'] );
  		$cat = $cat && !is_wp_error( $cat ) ? sprintf( __( 'the category "%s"','eos-dp' ),$cat->name ) : sprintf( __( 'Category id %s','eos-dp' ),(int) $_GET['eos_cat'] );
  		?><h2><?php printf( __( 'Results for %s','eos-dp' ),$cat ); ?></h2><?php
  		$args['category'] = sanitize_title( $_GET['eos_cat'] );
  	}
  	if( isset( $_GET['tax_name'] ) && isset( $_GET['term_slug'] ) ){
  		$args['tax_query'] = array(
        array(
  	      'taxonomy' => esc_attr( $_GET['tax_name'] ),
  	      'field' => 'slug',
  	      'terms' => esc_attr( $_GET['term_slug'] )
        )
      );
  	}
  	if( in_array( $this->post_type,array( 'post','page' ) ) ){
  		if( function_exists( 'eos_scfm_get_mobile_ids' ) ){
  			if( isset( $_GET['device'] ) && 'mobile' === $_GET['device'] ){
  				$args['post__in'] = eos_scfm_get_mobile_ids();
  			}
  			elseif( isset( $_GET['device'] ) && 'desktop' === $_GET['device'] ){
  				$args['post__not_in'] = eos_scfm_get_mobile_ids();
  			}
  		}
  	}
  	$this->is_home = false;
  	$this->is_relevant_pages = false;
  	$this->important_pages = eos_dp_important_pages();
  	if( isset( $_GET['eos_dp_home'] ) && 'true' === $_GET['eos_dp_home'] ){
  		$this->show_on_front = eos_dp_get_option( 'show_on_front' );
  		if( 'page' === $this->show_on_front ){
  			$this->is_home = true;
  		}
  	}
  	elseif( isset( $_GET['eos_dp_relevant_pages'] ) && 'true' === $_GET['eos_dp_relevant_pages'] ){
  		$this->is_relevant_pages = true;
  		$args['post__in'] = $this->important_pages['ids'];
  	}
  	$this->page_on_front = eos_dp_get_option( 'page_on_front' );
  	$page_for_posts = eos_dp_get_option( 'page_for_posts' );
  	if( 0 === absint( $this->page_on_front ) && absint( $page_for_posts ) > 0 ){
  		$this->page_on_front = absint( $page_for_posts );
  	}
  	$this->posts = !$this->is_home ? get_posts( $args ) : array( get_post( $this->page_on_front ) );
  	$this->fdp_is_single_post = 1 === count( $this->posts ) || ( isset( $_GET['eos_dp_post_in'] ) && absint( $_GET['eos_dp_post_in'] ) > 0 && isset( $_GET['single_post'] ) && 1 === absint( $_GET['single_post'] ) );
  	if( $this->fdp_is_single_post && !isset( $_GET['eos_dp_post_in'] ) ){
  		$single_post = $this->posts[0];
  		$this->single_post_id = $single_post->ID;
  	}
  	else{
  		$this->single_post_id = isset( $_GET['eos_dp_post_in'] ) ? absint( $_GET['eos_dp_post_in'] ) : false;
  		$taxs = get_taxonomies( array(),'objects' );
  	}
  	?><script> var is_single_post = <?php echo $this->fdp_is_single_post ? 'true' : 'false'; ?>;</script><?php
  	if( !$this->is_home && !$this->is_relevant_pages ){
      $count_posts = wp_count_posts( $this->post_type );
    	$published_posts = $count_posts->publish + $count_posts->future + $count_posts->draft + $count_posts->pending + $count_posts->private;
    	$pagesN = ceil( $published_posts/max( 1,$this->posts_per_page ) );
    	$current_page = isset( $_GET['eos_page'] ) ? $_GET['eos_page'] : 1;
      ?>
      <div id="eos-dp-pagination-wrp" class="right">
    		<?php if( $pagesN > 1 ){
    		require EOS_DP_PLUGIN_DIR.'/admin/templates/partials/eos-dp-singles-pagination.php';
    		?>
    		<div id="fdp-s-t-i">
    			<span id="eos-dp-toggle-search" class="hover dashicons dashicons-search" style="padding:10px"></span>
    			<span id="eos-dp-toggle-pagination" class="hover dashicons dashicons-editor-ul" style="padding:10px"></span>
    		</div>
    		<?php } ?>
    		<div id="eos-dp-order-wrp" class="eos-hidden">
    			<div class="eos-dp-display-data" style="display:inline-block">
    				<h4 style="margin-bottom:-1px"><?php _e( 'Number of posts','eos-dp' ); ?></h4>
    				<input id="eos-dp-posts-per-page" type="number" min="10" max="200" value="<?php echo $this->posts_per_page; ?>" />
    			</div>
    			<div class="eos-dp-display-data" style="display:inline-block">
    				<h4 style="margin-bottom:0"><?php _e( 'Order by','eos-dp' ); ?></h4>
    				<select id="eos-dp-orderby-sel">
    					<option value="title"<?php echo isset( $_GET['orderby'] ) && $_GET['orderby'] === 'title' ? ' selected' : ''; ?>><?php _e( 'Title','eos-dp' ); ?></option>
    					<option value="ID"<?php echo isset( $_GET['orderby'] ) && $_GET['orderby'] === 'ID' ? ' selected' : ''; ?>><?php _e( 'Post id','eos-dp' ); ?></option>
    					<option value="author"<?php echo isset( $_GET['orderby'] ) && $_GET['orderby'] === 'author' ? ' selected' : ''; ?>><?php _e( 'Author','eos-dp' ); ?></option>
    					<option value="date"<?php echo isset( $_GET['orderby'] ) && $_GET['orderby'] === 'date' ? ' selected' : ''; ?>><?php _e( 'Date','eos-dp' ); ?></option>
    					<option value="modified"<?php echo isset( $_GET['orderby'] ) && $_GET['orderby'] === 'modified' ? ' selected' : ''; ?>><?php _e( 'Last modified date','eos-dp' ); ?></option>
    				</select>
    			</div>
    			<div class="eos-dp-display-data" style="display:inline-block">
    				<h4 style="margin-bottom:0"><?php _e( 'Order','eos-dp' ); ?></h4>
    				<select id="eos-dp-order-sel">
    					<option value="ASC"<?php echo isset( $_GET['order'] ) && strtolower( $_GET['order'] ) === 'asc' ? ' selected' : ''; ?>><?php _e( 'Ascending','eos-dp' ); ?></option>
    					<option value="DESC"<?php echo isset( $_GET['order'] ) && strtolower( $_GET['order'] ) === 'desc' ? ' selected' : ''; ?>><?php _e( 'Descending','eos-dp' ); ?></option>
    				</select>
    			</div>
    			<?php
    			if( function_exists( 'eos_scfm_get_mobile_ids' ) && in_array( $this->post_type,array( 'post','page' ) ) ){
    			?>
    			<div class="eos-dp-display-data" style="display:inline-block">
    				<h4 style="margin-bottom:0"><?php _e( 'Device','eos-dp' ); ?></h4>
    				<select id="eos-dp-device">
    					<option value="all"<?php echo isset( $_GET['device'] ) && strtolower( $_GET['device'] ) === 'all' ? ' selected' : ''; ?>><?php _e( 'All devices','eos-dp' ); ?></option>
    					<option value="desktop"<?php echo isset( $_GET['device'] ) && strtolower( $_GET['device'] ) === 'desktop' ? ' selected' : ''; ?>><?php _e( 'Desktop devices','eos-dp' ); ?></option>
    					<option value="mobile"<?php echo isset( $_GET['device'] ) && strtolower( $_GET['device'] ) === 'mobile' ? ' selected' : ''; ?>><?php _e( 'Mobile devices','eos-dp' ); ?></option>
    				</select>
    			</div>
    			<?php
    			}
    			?>
    			<div class="eos-dp-display-data" style="margin-top:16px">
    				<a href="<?php echo add_query_arg( array( 'posts_per_page' => 30,'orderby'=>'title','order'=>'ASC' ),admin_url( 'admin.php?page=eos_dp_menu&eos_dp_post_type='.$this->post_type ) ); ?>" class="button" id="eos-dp-order-refresh"><?php _e( 'Show','eos-dp' ); ?></a>
    			</div>
    		</div>
    		<?php if( $pagesN > 1 ): ?>
    		<div class="eos-dp-search-wrp eos-hidden">
    			<div class="eos-dp-search-box" style="margin-bottom:8px">
    				<label class="screen-reader-text" for="post-search-input"><?php _e( 'Search','eos-dp' ); ?></label>
    				<input type="search" id="eos-dp-post-search" value="">
    				<input type="submit" id="eos-dp-post-search-submit" data-url="<?php echo add_query_arg( 'eos_post_title','',admin_url( 'admin.php?page=eos_dp_menu&eos_dp_post_type='.$this->post_type ) ); ?>" class="button" value="<?php _e( 'Search','eos-dp' ); ?>" />
    			</div>
    			<div class="eos-dp-search-box">
    				<label class="screen-reader-text" for="post-search-input"><?php _e( 'Search By Category','eos-dp' ); ?></label>
    				<div id="eos-dp-by-cat-search" style="display:inline-block"><?php wp_dropdown_categories(); ?></div>
    				<input type="submit" id="eos-dp-by-cat-search-submit" data-url="<?php echo add_query_arg( 'eos_cat','',admin_url( 'admin.php?page=eos_dp_menu&eos_dp_post_type='.$this->post_type ) ); ?>" class="button" value="<?php _e( 'Search By Category','eos-dp' ); ?>" />
    			</div>
    		</div>
    	<?php endif; ?>
    	</div>
      <?php

    }
  	$count_posts = wp_count_posts( $this->post_type );
  	$published_posts = $count_posts->publish + $count_posts->future + $count_posts->draft + $count_posts->pending + $count_posts->private;
  	$pagesN = ceil( $published_posts/max( 1,$this->posts_per_page ) );
  	$current_page = isset( $_GET['eos_page'] ) ? $_GET['eos_page'] : 1;
    if( $this->fdp_is_single_post ){
      add_filter( 'admin_footer_text','__return_false',999999 );
      add_filter( 'update_footer','__return_false',999999 );
      remove_all_actions( 'admin_footer' );
    }
    if( defined( 'ICL_SITEPRESS_VERSION' ) || function_exists( 'pll_languages_list' ) ){
      echo eos_dp_wpml_switcher();
    }
    ?>
    <h2 id="eos-dp-singles-title" style="margin-bottom:16px" data-post-type="<?php echo $this->post_type; ?>"><?php echo esc_html( $this->title ); ?></h2>
		<div>
		<?php if( $this->is_home  ){ ?>
			<span id="eos-dp-autosuggest-all" class="button" title="<?php _e( 'Suggest plugins','eos-dp' ); ?>"><?php _e( 'Suggest plugins','eos-dp' ); ?></span>
			<p><?php printf( __( 'Pressing the button above, FDP will suggest you the needed plugins. However, check the page preview with the lens icon %s before to save the options.','eos-dp' ),'<span class="dashicons dashicons-search"></span>' ); ?></p>
			<p><?php printf( __( 'With the %s you can have the auto-suggestion also on other pages.','eos-dp' ),'<a style="color:inherit" href="https://freesoul-deactivate-plugins.com/" target="_blank">'.__( 'PRO version','eos-dp' ).'</a>' ); ?></p>

    <?php
      if( eos_dp_get_option( 'eos_dp_critical_css' ) ){
        wp_nonce_field( 'fdp_generate_critical_css','fdp_generate_critical_css' );
        $onclick = 'eos_dp_send_ajax(jQuery(this),{"nonce" : document.getElementById("fdp_generate_critical_css").value,"url" : this.dataset.url,"action" : "eos_dp_generate_critical_css"});return false;';
      ?>
      <p><span id="fdp-generate-critical-css" class="button" title="<?php esc_attr__( 'Generate Critical CSS','eos-dp' ); ?>" data-url="<?php echo get_home_url(); ?>" onclick="<?php echo esc_js( $onclick ); ?>"><?php esc_html_e( 'Generate Critical CSS','eos-dp' ); ?></span></p>
      <?php
      }
    }
    ?>
			<p id="eos-dp-autosuggest-msg" class="eos-hidden notice notice-warning"><?php _e( 'It may take a couple of minutes, drink a coffee while we try to understand which plugins you need on this page','eos-dp' ); ?></p>
			<p id="eos-dp-autosuggest-msg-error" class="notice notice-error eos-hidden"><?php _e( 'Unable to finish the tests to suggest the unused plugins. Probably the server is too busy.','eos-dp' ); ?></p>
		</div>
		<?php do_action( 'eos_dp_after_singles_title' ); ?>
		<div id="eos-dp-table-head-actions"><?php do_action( 'eos_dp_pre_table_head' ); ?></div>
    <?php
  }

  public function tableBody( $page_slug ){
    if( $this->posts && !empty( $this->posts ) ){
      $ids = array();
      foreach( $this->posts as $post ){
        if( $post && is_object( $post ) ){
          $ids[] = $post->ID;
        }
      }
      $meta_valuesObj = eos_dp_get_multiple_metadata( '_eos_deactive_plugins_key',$ids );
      $meta_values = array();
      if( !empty( $meta_valuesObj ) ){
        foreach( $meta_valuesObj as $obj ){
          $meta_values[sanitize_key( $obj->post_id )] = sanitize_text_field( $obj->meta_value );
        }
      }
      $status_icons = array(
        'public' => '',
        'private' => '<span title="'.__( 'Private','eos-dp' ).'" class="dashicons dashicons-privacy"></span>',
        'draft' => '<span title="'.__( 'Draft','eos-dp' ).'" class="dashicons dashicons-hidden"></span>'
      );
      $row = 1;
      foreach( $this->posts as $post ){
        if( $post && is_object( $post ) && $post->post_type === $this->post_type ){
          $extra_class = esc_attr( apply_filters( 'fdp_singles_row_class','',$post ) );
          $desktop_id = 0;
          $mobileClass = '';
          if( in_array( $this->post_type,array( 'post','page' ) ) ){
            if( function_exists( 'eos_scfm_related_desktop_id' ) ){
              $desktop_id = eos_scfm_related_desktop_id( $post->ID );
              if( $desktop_id > 0 ){
                $mobileClass = ' eos-dp-mobile';
              }
            }
          }
          $loc = false;
          $flag = '';
          $post_id = $post->ID;
          if( function_exists( 'pll_get_post_language' ) ){
            $loc = pll_get_post_language( $post->ID );
            if( $loc && '' !== $loc ){
              $flag = defined( 'POLYLANG_FILE' ) && defined( 'POLYLANG_DIR' ) && file_exists( POLYLANG_DIR.'/flags/'.str_replace( 'en.png','england.png',$loc.'.png' ) ) ? '<img src="'.esc_url( plugins_url( '/flags/'.str_replace( 'en.png','england.png',$loc.'.png' ),POLYLANG_FILE ) ).'" />' : esc_html( strtoupper( $loc ) );
            }
            if( function_exists( 'pll_get_post' ) && !isset( $_GET['lang'] ) ){
              $post_id = absint( pll_get_post( $post->ID, $this->default_language ) );
            }
          }
          elseif( defined( 'ICL_SITEPRESS_VERSION' ) ){
            $loc = apply_filters( 'wpml_element_language_code',null,array( 'element_id' => $post->ID,'element_type' => 'post' ) );
            if( $loc && '' !== $loc ){
              $flag = defined( 'ICL_PLUGIN_URL' ) && defined( 'WPML_PLUGIN_PATH' ) && file_exists( WPML_PLUGIN_PATH.'/res/flags/'.$loc.'.png' ) ? '<img src="'.esc_url( ICL_PLUGIN_URL.'/res/flags/'.$loc.'.png' ).'" />' : esc_html( strtoupper( $loc ) );
            }
          }
          $values_string = isset( $meta_values[$post_id] ) ? $meta_values[$post_id] : '';
          $values = explode( ',',$values_string );
          $bin = substr( implode( '',array_map( 'eos_dp_is_not_empty_string',$values ) ),1 );
          $needCustom = false;
          if( $loc && strtolower( substr( $loc,0,2 ) ) !== strtolower( substr( $this->default_language,0,2 ) ) ){
            $need_custom_url[$post->ID] = get_permalink( $post->ID );
            $needCustom = true;
          }
          $locked = '';
          if( !$this->overridable || ( isset( $this->post_types_matrix_pt[3] ) && is_array( $this->post_types_matrix_pt[3] ) && !empty( $this->post_types_matrix_pt[3] ) && in_array( $post->ID,$this->post_types_matrix_pt[3] ) ) ){
            $locked = ' eos-post-locked';
          }
          if( $needCustom && !empty( $eos_dp_need_custom_url ) && !in_array( $post->ID,array_keys( $eos_dp_need_custom_url ) ) ){
            $locked = '';
          }
          $child_class = isset( $post->post_parent ) && absint( $post->post_parent ) > 0 ? ' fdp-row-is-child' : ' fdp-top-level-page';
          $args = array( 'test_id'=>time(),'fdp_post_id'=>$post->ID );
          $home_class = '';
          if( absint( $this->page_on_front ) === $post->ID ){
            $args['is_home'] = '1';
            $home_class = ' fdp-row-is-home';
          }
          $extra_dataset = '';
          if( $post_id !== $post->ID ){
            $extra_dataset .= ' data-default-lang-ID="'.esc_attr( $post->ID ).'"';
          }
          if( $flag && '' !== $flag && $loc !== $this->default_language ){
            $extra_class .= ' fdp-translated-page';
          }
          if( $this->fdp_is_single_post ){
            $extra_class .= ' fdp-actions-on';
          }
          $woo = isset( $this->important_pages['woo_ids'] ) && !empty( $this->important_pages['woo_ids'] ) && in_array( $post->ID,$this->important_pages['woo_ids'] );
        ?>
          <tr<?php echo $extra_dataset; ?> data-url="<?php echo esc_attr( str_replace( $this->home_url,'',get_permalink( $post->ID ) ) ); ?>" data-active-plugins="<?php echo substr_count( $bin,'1' ); ?>" data-disabled-plugins="<?php echo substr_count( $bin,'0' ); ?>"  data-bin="<?php echo esc_attr( $bin ); ?>" class="fdp-row-<?php echo $row; ?> eos-dp-post-row eos-dp-post-<?php echo $this->post_type.$mobileClass.$locked.$child_class.$home_class.$extra_class;echo $woo ? ' eos-dp-woo-row' : '';echo isset( $status_icons[$post->post_status] ) ? ' fdp-row-'.$post->post_status : '';echo isset( $this->important_pages['nav_ids'] ) && !empty( $this->important_pages['nav_ids'] ) && in_array( $post->ID,$this->important_pages['nav_ids'] ) ? ' fdp-in-nav' : '';?>" data-post-id="<?php echo $post->ID; ?>" data-row_id="<?php echo esc_attr( $post->ID ); ?>">
            <?php
            if( isset( $post->post_title ) ){
              ?>
              <td class="eos-dp-post-name-wrp">
                <span class="fdp-row-actions-ico dashicons dashicons-plus" title="<?php __( 'Action buttons','eos-dp' ); ?>"></span>
                <span class="eos-dp-lock-post-wrp"><input data-row="<?php echo esc_attr( $row ); ?>" class="eos-dp-lock-post" type="checkbox" /></span>
                <span class="eos-dp-not-active-wrp"><input title="<?php printf( __( 'Activate/deactivate all plugins in %s','eos-dp' ),esc_attr( $post->post_title ) ); ?>" data-row="<?php echo esc_attr( $row ); ?>" class="eos-dp-global-chk-row" type="checkbox" /></span>
                <span class="eos-dp-title">
                <?php
                  if( 1 === $row ) $this->resize_col();
                  echo '<span class="fdp-title-text">';
                  echo '' !== $post->post_title ? esc_html( $post->post_title ) : sprintf( __( 'Untitled (post id:%s)','eos-dp' ),$post->ID );
                  echo '</span>';
                  echo isset( $status_icons[$post->post_status] ) ? $status_icons[$post->post_status] : '';
                  echo $woo ? '<span class="dashicons dashicons-cart"></span>' : '';
                  echo isset( $this->important_pages['nav_ids'] ) && !empty( $this->important_pages['nav_ids'] ) && in_array( $post->ID,$this->important_pages['nav_ids'] ) ? '<span title="'.__( 'Included in the navigation','eos-dp' ).'" class="dashicons dashicons-menu-alt2"></span>' : '';
                  if( $desktop_id > 0 ){
                    $desktop_title = get_the_title( $desktop_id );
                    ?><span class="eos-dp-mobile dashicons dashicons-smartphone"></span><?php
                  }
                  ?>
                  <span><?php echo $flag; ?></span>
                </span>
                <?php if( strlen( $post->post_title ) > 46 ){ ?>
                <span class="fdp-long-title"><?php echo esc_html( $post->post_title ); ?></span>
                <?php } ?>
                <?php if( ' fdp-row-is-home' === $home_class ){
                  ?><span class="dashicons dashicons-admin-home"></span><?php
                }
                if( $this->is_hierarchical ){
                if( isset( $post->post_parent ) && absint( $post->post_parent ) > 0 ){
                ?>
                  <span class="fdp-child-page dashicons dashicons-networking"></span>
                <?php }else{ ?>
                  <span style="display:none" class="fdp-parent-page dashicons dashicons-networking"></span>
                <?php }
                }
                ?>
                <?php include EOS_DP_PLUGIN_DIR.'/admin/templates/partials/eos-dp-action-buttons.php'; ?>
              </td>
              <?php
              $k = 0;
              foreach( $this->active_plugins as $plugin ){
                if( in_array( $plugin,array_keys( $this->plugins_by_dirs ) ) ){
                ?>
                <td data-path="<?php echo esc_attr( $plugin ); ?>" class="<?php echo !in_array( $plugin,$values ) ? 'eos-dp-active' : ''; ?>">
                  <div class="eos-dp-td-chk-wrp">
                    <input class="eos-dp-row-<?php echo $row; ?> eos-dp-col-<?php echo $k + 1; ?>" data-checked="<?php echo in_array( $plugin,$values ) ? 'checked' : 'not-checked'; ?>" type="checkbox"<?php echo in_array( $plugin,$values ) ? ' checked' : ''; ?> />
                  </div>
                </td>
                <?php
                ++$k;
                }
              }
            } ?>
          </tr>
          <?php
          ++$row;
        }
      }
    }
  }

  public function legend(){
  ?>
    <span>
      <span class="eos-dp-locked-wrp eos-dp-icon-wrp" style="position:relative"><span class="eos-post-locked-icon" style="width:40px;height:21px"></span>
      <span class="eos-dp-no-decoration fdp-has-tooltip">
        <span class="dashicons dashicons-editor-help" style="font-size:24px"></span>
        <p class="fdp-tooltip" style="width:auto;white-space:inherit"><?php printf( __( 'The row settings will override the %sPost Types settings%s.','eos-dp' ),'<a href="'.admin_url( '?page=eos_dp_by_post_type' ).'" target="_fdp_post_types">','</a>' ); ?></p>
      </span>
    </span>
    <span>&nbsp;&nbsp;&nbsp;</span>
    <span>
      <span class="eos-dp-unlocked-wrp eos-dp-icon-wrp" style="position:relative"><span class="eos-post-unlocked-icon" style="width:40px;height:19px"></span>
      <span class="eos-dp-no-decoration fdp-has-tooltip">
        <span class="dashicons dashicons-editor-help" style="font-size:24px"></span>
        <p class="fdp-tooltip" style="width:auto;white-space:inherit"><?php printf( __( 'The %sPost Types settings%s will override the row settings.','eos-dp' ),'<a href="'.admin_url( '?page=eos_dp_by_post_type' ).'" target="_fdp_post_types">','</a>' ); ?></p>
      </span>
    </span>
    <?php if( !$this->fdp_is_single_post ){ ?>
    <div style="margin-top:16px">
      <span id="eos-dp-lock-all" class="button<?php echo $this->is_home ? ' eos-hidden' : ''; ?>">
        <?php esc_html_e( 'Activate all rows','eos-dp-pro' ); ?>
      </span>
      <span id="eos-dp-unlock-all" class="button<?php echo $this->is_home ? ' eos-hidden' : ''; ?>">
        <?php esc_html_e( 'Disable all rows','eos-dp-pro' ); ?>
      </span>
    </div>
    <?php do_action( 'fdp_before_row_filters' ); ?>
    <div id="fdp-show-page-filters-wrp" style="margin-top:16px"><span id="fdp-show-page-filters" class="button"><?php _e( 'Page Filters','eos-dp' ); ?><span class="dashicons dashicons-arrow-down" style="font-size:28px"></span></span></div>
    <div id="fdp-singles-filter" class="eos-hidden" style="position:absolute">
      <p style="margin-top:6px">
        <span title="<?php _e( 'Show all','eos-dp' ); ?>" style="color:initial;border-color:initial" class="eos-active button fdp-filter-all"><?php _e( 'Show all','eos-dp' ); ?></span>
      </p>
      <div>
        <span title="<?php _e( 'Homepage','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-admin-home" data-class=".fdp-row-is-home"></span>
        <span title="<?php _e( 'Active rows','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-yes" data-class=".eos-post-locked"></span>
        <span title="<?php _e( 'Not active rows','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-no-alt" data-class=".eos-dp-post-row:not(.eos-post-locked)"></span>
        <span title="<?php _e( 'Included in the navigation','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-menu-alt2" data-class=".fdp-in-nav"></span>
        <span title="<?php _e( 'Private','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-privacy" data-class=".fdp-row-private"></span>
        <br/>
        <?php if( $this->is_hierarchical ){ ?>
        <span title="<?php _e( 'Child page','eos-dp' ); ?>" class="eos-dp-active hover fdp-child-page dashicons dashicons-networking" data-class=".fdp-row-is-child"></span>
        <span title="<?php _e( 'Top level page','eos-dp' ); ?>" class="eos-dp-active hover fdp-parent-page dashicons dashicons-networking" data-class=".fdp-top-level-page"></span>
        <?php } ?>
        <span title="<?php _e( 'Plugins all active','eos-dp' ); ?>" class="eos-dp-active hover fdp-all-active dashicons dashicons-plugins-checked" data-class="[data-disabled-plugins='0']"></span>
        <span title="<?php _e( 'Plugins all disabled','eos-dp' ); ?>" class="eos-dp-active hover fdp-all-disabled dashicons dashicons-admin-plugins" data-class="[data-active-plugins='0']"></span>
        <?php
        if( function_exists( 'eos_scfm_post_types' ) ){ ?>
          <span title="<?php _e( 'Mobile','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-smartphone" data-class=".eos-dp-mobile"></span>
        <?php } ?>
        <?php if( class_exists( 'WooCommerce') && 'page' === $this->post_type){ ?>
        <span title="<?php _e( 'WooCommerce pages','eos-dp' ); ?>" class="eos-dp-active hover dashicons dashicons-cart" data-class=".eos-dp-woo-row"></span>
      <?php } ?>
      </div>
    </div>
    <?php do_action( 'fdp_after_row_filters' ); ?>
    <?php }else{ ?>
    <div style="clear:both"></div>
    <?php }
  }
}
