<?php
defined( 'ABSPATH' ) || exit;

class FDP_Terms_Archives_Page extends Eos_Fdp_Matrix_Page {
  public $default_languae;
  public $current_tax;
  public $tax;
  public $terms;
  public $permalink_structure;
  public $home_url;
  public $archiveSetts;
  public $option_size;
  public $skip_db;

  
  public function init(){
    $opts = eos_dp_get_option( 'eos_dp_opts' );
    $this->skip_db = ( isset( $opts['skip_db_for_archives'] ) && 'true' ===  $opts['skip_db_for_archives'] ) || ( defined( 'FDP_SKIP_DB_FOR_ARCHIVES' ) && FDP_SKIP_DB_FOR_ARCHIVES );
    $this->section_id = 'eos-dp-by-archive-section';
    $this->default_language = eos_dp_default_language();
    $this->current_tax = isset( $_GET['eos_dp_tax'] ) ? sanitize_key( $_GET['eos_dp_tax'] ) : 'category';
    $this->tax = get_taxonomy( $this->current_tax );
    $this->terms = get_terms( array( 'taxonomy' => $this->tax->name,'hide_empty' => false,'orderby' => 'name','order' => 'ASC' ) );
    $this->permalink_structure = eos_dp_get_option( 'permalink_structure' );
    $this->home_url = get_option( 'home' );
    $this->archiveSetts = eos_dp_get_option( 'eos_dp_archives' );
    $this->option_size = eos_dp_get_option_size( 'eos_dp_archives' );
    if( $this->option_size > 120 ){
      add_action( 'fdp_top_bar_notifications',function(){
        $msg = '<p>'.__( 'The option Archives and Terms Archives is becoming too big and they may worsening the performance. Maybe better you move this option from the database to the filesystem.','eos-dp' ).'</p>';
        $msg .= '<p>'.sprintf( __( 'If you want to do it go to %sExperiments%s','eos-dp' ),'<a href="'.add_query_arg( 'page','eos_dp_experiments',admin_url( 'admin.php' ) ).'" title="'.__( 'Experiments','eos-dp' ).'">','</a>' ).'</p>';
        eos_dp_display_admin_notice( 'eos_dp_archives',__( 'Option Archives and Terms Archives too big.','eos-dp' ),$msg,'warning' );
      } );
    }
  }

  public function before_section( $page_slug ){
  	wp_nonce_field( 'eos_dp_key', 'eos_dp_key' );
  	wp_nonce_field( 'eos_dp_pro_gpsi_test','eos_dp_pro_gpsi_test' );
  	wp_nonce_field( 'eos_dp_pro_gt_metrix_test','eos_dp_pro_gt_metrix_test' );
  	if( isset( $_GET['eos_dp_home'] ) && 'true' === $_GET['eos_dp_home'] ){
  		wp_nonce_field( 'eos_dp_pro_auto_settings', 'eos_dp_pro_auto_settings' );
  	}
    if( defined( 'ICL_SITEPRESS_VERSION' ) || function_exists( 'pll_languages_list' ) ){
  		echo eos_dp_wpml_switcher();
  	}
    ?>
    <style id="fdp-archives-css">
    .fdp-all-archives-row .eos-dp-title{
      text-transform:uppercase;
      font-weight:bold
    }
    .fdp-all-archives-row{
      position:relative
    }
    .fdp-all-archives-row:after {
      content: " ";
      position: absolute;
      bottom: 0;
      height: 3px;
      background-color: #a28754;
      left: 0;
      right: 0;
      z-index: 9;
    }
    </style>
    <p><?php printf( esc_html__( 'If you need to disabe the same plugins on all archives, use the row All %s','eos-dp' ),$this->tax->labels->name ); ?> (beta)</p>
    <?php
  	if( false === strpos( $this->permalink_structure,'%category%' ) && '.' === eos_dp_get_option( 'category_base' ) ){
  	?>
  	<div id="eos-dp-plain-permalink-wrg" style="line-height:1;margin:20px 0;padding:10px;color:#23282d;background:#fff;border-<?php echo is_rtl() ? 'right' : 'left'; ?>:4px solid  #dc3232">
  		<div>
  			<h1><?php printf( __( "Issue detected. In the %spermalinks settings%s you have a full stop as base category, and you don't have %s in your custom permalink structure.",'eos-dp' ),'<a href="'.admin_url( 'options-permalink.php' ).'" target="_blank">','</a>','%category%' ); ?></h1>
  			<h1><?php __( "The plugins control will probably not work for term archives.",'eos-dp' ); ?></h1>
  			<h1><?php printf( __( "If you really want these permalink settings, you need %sthe custom URLs%s for the term archives.",'eos-dp' ),'<a href="'.admin_url( 'admin.php?page=eos_dp_url' ).'" target="_blank">','</a>' ); ?></h1>
  		</div>
  		<div>
  			<a class="button" target="_blank" href="<?php echo admin_url( 'options-permalink.php' ); ?>"><?php  _e( 'Check Permalinks Structure','eos-dp' ); ?></a>
  		</div>
  	</div>
    <?php
    }
  }
  public function tableBody( $page_slug ){
    $row = 1;
    if( $this->tax && isset( $this->tax->labels ) ){
      $tax_labels = $this->tax->labels;
      ?>
      <h2 id="eos-dp-terms-archives-title"><?php echo esc_html( $tax_labels->name ); ?></h2>
      <?php do_action( 'eos_dp_after_terms_archive_title' ); ?>
      <?php
    }
    if( !empty( $this->terms ) ){
      $all_terms = $this->terms;
      if( count( $all_terms ) > 30 ){
        $letters = array();
        $filters = '<div id="fdp-filters-letters">';
        $get = $_GET;
        if( isset( $get['l'] ) ){
          unset( $get['l'] );
        }
        $get = array_map( 'sanitize_text_field',$get );
        $filters .= '<a class="fdp-filter-letter button" href="'.esc_url( add_query_arg( $get,admin_url( 'admin.php' ) ) ).'">'.esc_attr__( 'All','eos-dp' ).'</a>';
        foreach( $all_terms as $term ){
          $l = esc_attr( strtolower( mb_substr( $term->name,0,1 ) ) );
          if( !in_array( $l,$letters ) ){
            $letters[] = $l;
            $filters .= '<a class="fdp-filter-letter button" href="'.esc_url( add_query_arg( array_merge( array( 'l' => $l ),$get ),admin_url( 'admin.php' ) ) ).'">'.esc_attr( ucfirst( $l ) ).'</a>';
          }
        }
        $filters .= '<p style="margin:0"><small>'.esc_html__( 'Filter by letter','eos-dp' ).'</small></p></div>';
        echo $filters;
       }
      $all_archives = new stdClass();
      $all_archives->term_id = 0;
      $all_archives->taxonomy = $this->tax->name;
      $all_archives->slug = isset( $this->tax->rewrite ) && isset( $this->tax->rewrite['slug'] ) ? 'all_archives_'.$this->tax->rewrite['slug'] : 'all_archives_'.$this->tax->name;
      $all_archives->name = sprintf( __( 'All %s','eos-dp' ),$this->tax->labels->name );
      array_unshift( $all_terms,$all_archives );
      foreach( $all_terms as $term ){
        $active = false;
        $labels_name = $term -> name;
        if( isset( $_GET['l'] ) && sanitize_text_field( strtolower( $_GET['l'] ) ) !== strtolower( mb_substr( $labels_name,0,1 ) ) && 'all' !== sanitize_text_field( strtolower( $_GET['l'] ) ) ){
          --$row;
          continue;
        }
        $archive_url = get_term_link( $term );
        $flag = '';
        $loc = false;
        if( defined( 'ICL_SITEPRESS_VERSION' ) ){
          $loc = apply_filters( 'wpml_element_language_code',null,array('element_id' => $term->term_id, 'element_type' => $term->taxonomy ) );
          if( $loc && '' !== $loc ){
            $flag = defined( 'ICL_PLUGIN_URL' ) && defined( 'WPML_PLUGIN_PATH' ) && file_exists( WPML_PLUGIN_PATH.'/res/flags/'.$loc.'.png' ) ? ' <img src="'.esc_url( ICL_PLUGIN_URL.'/res/flags/'.$loc.'.png' ).'" />' : esc_html( strtoupper( $loc ) );
          }
        }
        if( function_exists( 'pll_get_term_language' ) ){
          $loc = pll_get_term_language( $term->term_id );
          if( $loc && '' !== $loc ){
            $flag = defined( 'POLYLANG_FILE' ) && defined( 'POLYLANG_DIR' ) && file_exists( POLYLANG_DIR.'/flags/'.str_replace( 'en.png','england.png',$loc.'.png' ) ) ? ' <img src="'.esc_url( plugins_url( '/flags/'.str_replace( 'en.png','england.png',$loc.'.png' ),POLYLANG_FILE ) ).'" />' : esc_html( strtoupper( $loc ) );
          }
        }
        if( $loc && $loc === $this->default_language ){
          $archive_urlA = explode( '?',$archive_url );
          $archive_url = $archive_urlA[0];
        }
        if( !is_wp_error( $archive_url ) ){
          $kArr = explode( '//',$archive_url );
          if( isset( $kArr[1] ) ){
            $key = $kArr[1];
          }
          $key = 1 === $row ? $all_archives->slug : sanitize_key( str_replace( '/','__',rtrim( $key,'/' ) ) );
          $this->permalink_structure = eos_dp_get_option( 'permalink_structure' );
          if( false !== strpos( $this->permalink_structure,'%category%' ) && '%postname%' === basename( $this->permalink_structure )  && '.' === eos_dp_get_option( 'category_base' ) ){
            $key = str_replace( '__.__','__',$key );

          }
          if( !$this->skip_db){
            $values = isset( $this->archiveSetts[$key] ) ? explode( ',',$this->archiveSetts[$key] ) : array_fill( 0,count( $this->active_plugins ),',' );
          }
          else{
            $opts_by_path = eos_dp_get_opts_by_url( esc_attr( str_replace( $this->home_url,'',$archive_url ) ) );
            if( isset( $opts_by_path['post_id'] ) && 'archive' === $opts_by_path['post_id'] ){
              $values = isset( $opts_by_path['plugins'] ) ? explode( ',',$opts_by_path['plugins'] ) : array_fill( 0,count( $this->active_plugins ),',' );
            }
          }
          if( !isset( $values ) ){
            $values = array_fill( 0,count( $this->active_plugins ),',' );
          }
          ?>
          <tr class="eos-dp-archive-row eos-dp-post-row<?php echo 1 === $row && ( !isset( $_GET['l'] ) || 'all' === $_GET['l'] ) ? ' fdp-all-archives-row' : '';echo 1 === $row && defined( 'FDP_SKIP_DB_FOR_ARCHIVES' ) && FDP_SKIP_DB_FOR_ARCHIVES && ( !isset( $_GET['l'] ) || 'all' === $_GET['l'] ) ? ' eos-no-events' : ''; ?>" data-url="<?php echo esc_attr( str_replace( $this->home_url,'',$archive_url ) ); ?>" data-post-type="<?php echo esc_attr( $term -> name ); ?>" data-tax="<?php echo esc_attr( $this->tax->name ); ?>" data-href="<?php echo 1 === $row && ( !isset( $_GET['l'] ) || 'all' === $_GET['l'] ) ? esc_attr( $all_archives->slug ) : esc_url( $archive_url ); ?>">
            <td class="eos-dp-post-name-wrp">
              <span class="fdp-row-actions-ico dashicons dashicons-plus" title="<?php __( 'Action buttons','eos-dp' ); ?>"></span>
              <span class="eos-dp-not-active-wrp"><input title="<?php printf( __( 'Activate/deactivate all plugins in %s','eos-dp' ),esc_attr( $labels_name ) ); ?>" data-row="<?php echo esc_attr( $row ); ?>" class="eos-dp-global-chk-row" type="checkbox" /></span>
              <span class="eos-dp-title"><?php echo 1 === $row && ( !isset( $_GET['l'] ) || 'all' === $_GET['l'] ) ? $all_archives->name.' (beta)' : sprintf( __( '%s Archive','eos-dp' ),$labels_name );echo $flag; ?></span>
              <div class="eos-dp-actions">
                <?php eos_dp_debug_button( $archive_url );
                if( isset( $this->tax->object_type ) ){
                $post_types = $this->tax->object_type;
                $singles_url = admin_url( add_query_arg(
                  array(
                    'page' => 'eos_dp_menu',
                    'tax_name' => esc_attr( $this->tax->name ),
                    'term_slug' => esc_attr( $term->slug ),
                    'eos_dp_post_type' => esc_attr( $post_types[0] )
                  ),
                  'admin.php'
                ) );
                ?>
                <a class="fdp-has-tooltip fdp-right-tooltip" href="<?php echo esc_url( $singles_url ); ?>">
                  <span class="dashicons dashicons-admin-post"></span>
                  <div class="fdp-tooltip"><?php _e( 'Go to Singles settings','eos-dp' ); ?></div>
                </a>
                <?php } ?>

                <?php eos_dp_saved_preview_button( $archive_url,$key ); ?>
                <?php
                $themes_list = eos_dp_active_themes_list();
                if( $themes_list ){
                ?>
                <a class="eos-dp-theme-sel fdp-has-tooltip fdp-right-tooltip" style="border:1px solid #fff !important">
                  <?php echo $themes_list; ?>
                  <div class="fdp-tooltip"><?php _e( 'Select a different Theme and then click on the lens icon to see the preview','eos-dp' ); ?></div>
                </a>
                <?php } ?>
                <a class="eos-dp-preview eos-dp-archive-preview fdp-has-tooltip" oncontextmenu="return false;" href="<?php echo wp_nonce_url( add_query_arg( array( 'test_id'=>time(),'fdp_tax'=>esc_attr( $this->tax->name ) ),esc_url( $archive_url ) ),'eos_dp_preview','eos_dp_preview' ); ?>" target="_blank">
                  <span class="dashicons dashicons-search"></span>
                  <div class="fdp-tooltip"><?php _e( 'Preview the page loading plugins according the settings you see now on this row and the selected theme','eos-dp' ); ?></div>
                </a>
                <a data-page_speed_insights="false" class="eos-dp-preview fdp-has-tooltip" oncontextmenu="return false;" href="<?php echo wp_nonce_url( add_query_arg( array_merge( array( 'test_id'=>time(),'fdp_tax'=>esc_attr( $this->tax->name ),'show_files' => 'true' ) ),esc_url( $archive_url ) ),'eos_dp_preview','eos_dp_preview' ); ?>" target="_blank">
                  <span class="dashicons dashicons-search">
                    <span class="dashicons dashicons-media-code"></span>
                  </span>
                  <div class="fdp-tooltip"><?php _e( 'Preview the page loading plugins according the settings you see now on this row and the selected theme','eos-dp' ); ?></div>
                </a>
                <a class="eos-dp-preview fdp-has-tooltip" oncontextmenu="return false;" href="<?php echo wp_nonce_url( add_query_arg( array( 'js' => 'off','test_id'=>time(),'fdp_tax'=>esc_attr( $this->tax->name ) ),esc_url( $archive_url ) ),'eos_dp_preview','eos_dp_preview' ); ?>" target="_blank">
                  <span class="dashicons dashicons-search">
                    <span class="eos-dp-no-js">JS</span>
                  </span>
                  <div class="fdp-tooltip"><?php _e(  'Preview the page loading plugins and the theme according the settings you see now on this row and disable JavaScript esecution','eos-dp' ); ?></div>
                </a>
                <a class="eos-dp-invert-selection fdp-has-tooltip" href="#"><span class="dashicons"><span style="display:inline-block"><span class="fdp-invert-up"></span><span class="fdp-invert-down"></span></span></span>
                  <div class="fdp-tooltip"><?php _e( 'Invert selection','eos-dp' ); ?></div>
                </a>
                <a class="eos-dp-copy fdp-has-tooltip" href="#"><span class="dashicons dashicons-admin-page"></span>
                  <div class="fdp-tooltip"><?php _e( 'Copy this row settings','eos-dp' ); ?></div>
                </a>
                <a class="eos-dp-paste fdp-has-tooltip" href="#"><span class="dashicons dashicons-category"></span>
                  <div class="fdp-tooltip"><?php _e( 'Paste last copied row settings','eos-dp' ); ?></div>
                </a>
                <?php do_action( 'eos_dp_action_buttons' ); ?>
                <?php do_action( 'eos_dp_archive_action_buttons' ); ?>
                <a title="<?php _e( 'Close','eos-dp' ); ?>" class="eos-dp-close-actions" href="#"><span class="dashicons dashicons-no-alt"></span></a>
              </div>
            </td>
            <?php
            $k = 0;
            foreach( $this->active_plugins as $plugin ){
              if( in_array( $plugin,array_keys( $this->plugins_by_dirs ) ) ){
                $active = !isset( $values ) || !$values || !is_array( $values ) || !in_array( $plugin,$values ) ? true : false;
            ?>
            <td class="center<?php echo $active ? ' eos-dp-active' : ''; ?>" data-path="<?php echo esc_attr( $plugin ); ?>">
              <div class="eos-dp-td-chk-wrp eos-dp-td-archive-chk-wrp">
                <input class="eos-dp-row-<?php echo $row; ?> eos-dp-col-<?php echo $k + 1; ?> eos-dp-col-<?php echo ( $k + 1 ).'-'.$term -> name; ?>" data-checked="<?php echo $active ? 'not-checked' : 'checked'; ?>" type="checkbox"<?php echo !$active ? ' checked' : ''; ?> />
              </div>
            </td>
            <?php ++$k; } } ?>
          </tr>
          <?php
          ++$row;
        }
      }

    }
    else{
      ?>
      <p><?php printf( __( 'You have no %s','eos-dp' ),esc_html( $this->tax->label ) ); ?></p>
      <?php
    }
  }

}
