<?php
defined( 'ABSPATH' ) || exit;
//Define woocommerce functions if other plugins don't check properly the existence of WooCommerce and use one of those functions

if( !function_exists( 'get_woocommerce_price_format' ) ){
  function get_woocommerce_price_format(){
    $currency_pos = get_option( 'woocommerce_currency_pos' );
    $format       = '%1$s%2$s';
    switch ( $currency_pos ) {
      case 'left':
        $format = '%1$s%2$s';
        break;
      case 'right':
        $format = '%2$s%1$s';
        break;
      case 'left_space':
        $format = '%1$s&nbsp;%2$s';
        break;
      case 'right_space':
        $format = '%2$s&nbsp;%1$s';
        break;
    }
    return apply_filters( 'woocommerce_price_format',$format,$currency_pos );
  }
}

if( !function_exists( 'wc_get_page_id' ) ){
  function wc_get_page_id( $page ) {
    if ( 'pay' === $page || 'thanks' === $page ) {
      $page = 'checkout';
    }
    if ( 'change_password' === $page || 'edit_address' === $page || 'lost_password' === $page ) {
      $page = 'myaccount';
    }

    $page = apply_filters( 'woocommerce_get_' . $page . '_page_id', get_option( 'woocommerce_' . $page . '_page_id' ) );

    return $page ? absint( $page ) : -1;
  }
}
if( !function_exists( 'wc_get_page_permalink' ) ){
  function wc_get_page_permalink( $page, $fallback = null ) {
    $page_id   = wc_get_page_id( $page );
    $permalink = 0 < $page_id ? get_permalink( $page_id ) : '';
    if ( ! $permalink ) {
      $permalink = is_null( $fallback ) ? get_home_url() : $fallback;
    }
    return apply_filters( 'woocommerce_get_' . $page . '_page_permalink', $permalink );
  }
}
if( !function_exists( 'wc_get_cart_url' ) ){
  function wc_get_cart_url() {
    return apply_filters( 'woocommerce_get_cart_url', wc_get_page_permalink( 'cart' ) );
  }
}
if( !function_exists( 'wc_get_checkout_url' ) ){
  function wc_get_checkout_url() {
    $checkout_url = wc_get_page_permalink( 'checkout' );
    if ( $checkout_url ) {
      // Force SSL if needed.
      if ( is_ssl() || 'yes' === get_option( 'woocommerce_force_ssl_checkout' ) ) {
        $checkout_url = str_replace( 'http:', 'https:', $checkout_url );
      }
    }

    return apply_filters( 'woocommerce_get_checkout_url', $checkout_url );
  }
}

if( !function_exists( 'get_woocommerce_currency' ) ){
  function get_woocommerce_currency() {
    return apply_filters( 'woocommerce_currency', get_option( 'woocommerce_currency' ) );
  }
}

if( !function_exists( 'get_woocommerce_currency_symbol' ) ){
  function get_woocommerce_currency_symbol( $currency = '' ) {
    if ( ! $currency ) {
      $currency = get_woocommerce_currency();
    }
    $symbols = get_woocommerce_currency_symbols();
    $currency_symbol = isset( $symbols[ $currency ] ) ? $symbols[ $currency ] : '';
    return apply_filters( 'woocommerce_currency_symbol', $currency_symbol, $currency );
  }
}

if( !function_exists( 'get_woocommerce_currency_symbols' ) ){
  function get_woocommerce_currency_symbols() {
  	$symbols = apply_filters(
  		'woocommerce_currency_symbols',
  		array(
  			'AED' => '&#x62f;.&#x625;',
  			'AFN' => '&#x60b;',
  			'ALL' => 'L',
  			'AMD' => 'AMD',
  			'ANG' => '&fnof;',
  			'AOA' => 'Kz',
  			'ARS' => '&#36;',
  			'AUD' => '&#36;',
  			'AWG' => 'Afl.',
  			'AZN' => 'AZN',
  			'BAM' => 'KM',
  			'BBD' => '&#36;',
  			'BDT' => '&#2547;&nbsp;',
  			'BGN' => '&#1083;&#1074;.',
  			'BHD' => '.&#x62f;.&#x628;',
  			'BIF' => 'Fr',
  			'BMD' => '&#36;',
  			'BND' => '&#36;',
  			'BOB' => 'Bs.',
  			'BRL' => '&#82;&#36;',
  			'BSD' => '&#36;',
  			'BTC' => '&#3647;',
  			'BTN' => 'Nu.',
  			'BWP' => 'P',
  			'BYR' => 'Br',
  			'BYN' => 'Br',
  			'BZD' => '&#36;',
  			'CAD' => '&#36;',
  			'CDF' => 'Fr',
  			'CHF' => '&#67;&#72;&#70;',
  			'CLP' => '&#36;',
  			'CNY' => '&yen;',
  			'COP' => '&#36;',
  			'CRC' => '&#x20a1;',
  			'CUC' => '&#36;',
  			'CUP' => '&#36;',
  			'CVE' => '&#36;',
  			'CZK' => '&#75;&#269;',
  			'DJF' => 'Fr',
  			'DKK' => 'DKK',
  			'DOP' => 'RD&#36;',
  			'DZD' => '&#x62f;.&#x62c;',
  			'EGP' => 'EGP',
  			'ERN' => 'Nfk',
  			'ETB' => 'Br',
  			'EUR' => '&euro;',
  			'FJD' => '&#36;',
  			'FKP' => '&pound;',
  			'GBP' => '&pound;',
  			'GEL' => '&#x20be;',
  			'GGP' => '&pound;',
  			'GHS' => '&#x20b5;',
  			'GIP' => '&pound;',
  			'GMD' => 'D',
  			'GNF' => 'Fr',
  			'GTQ' => 'Q',
  			'GYD' => '&#36;',
  			'HKD' => '&#36;',
  			'HNL' => 'L',
  			'HRK' => 'kn',
  			'HTG' => 'G',
  			'HUF' => '&#70;&#116;',
  			'IDR' => 'Rp',
  			'ILS' => '&#8362;',
  			'IMP' => '&pound;',
  			'INR' => '&#8377;',
  			'IQD' => '&#x639;.&#x62f;',
  			'IRR' => '&#xfdfc;',
  			'IRT' => '&#x062A;&#x0648;&#x0645;&#x0627;&#x0646;',
  			'ISK' => 'kr.',
  			'JEP' => '&pound;',
  			'JMD' => '&#36;',
  			'JOD' => '&#x62f;.&#x627;',
  			'JPY' => '&yen;',
  			'KES' => 'KSh',
  			'KGS' => '&#x441;&#x43e;&#x43c;',
  			'KHR' => '&#x17db;',
  			'KMF' => 'Fr',
  			'KPW' => '&#x20a9;',
  			'KRW' => '&#8361;',
  			'KWD' => '&#x62f;.&#x643;',
  			'KYD' => '&#36;',
  			'KZT' => '&#8376;',
  			'LAK' => '&#8365;',
  			'LBP' => '&#x644;.&#x644;',
  			'LKR' => '&#xdbb;&#xdd4;',
  			'LRD' => '&#36;',
  			'LSL' => 'L',
  			'LYD' => '&#x644;.&#x62f;',
  			'MAD' => '&#x62f;.&#x645;.',
  			'MDL' => 'MDL',
  			'MGA' => 'Ar',
  			'MKD' => '&#x434;&#x435;&#x43d;',
  			'MMK' => 'Ks',
  			'MNT' => '&#x20ae;',
  			'MOP' => 'P',
  			'MRU' => 'UM',
  			'MUR' => '&#x20a8;',
  			'MVR' => '.&#x783;',
  			'MWK' => 'MK',
  			'MXN' => '&#36;',
  			'MYR' => '&#82;&#77;',
  			'MZN' => 'MT',
  			'NAD' => 'N&#36;',
  			'NGN' => '&#8358;',
  			'NIO' => 'C&#36;',
  			'NOK' => '&#107;&#114;',
  			'NPR' => '&#8360;',
  			'NZD' => '&#36;',
  			'OMR' => '&#x631;.&#x639;.',
  			'PAB' => 'B/.',
  			'PEN' => 'S/',
  			'PGK' => 'K',
  			'PHP' => '&#8369;',
  			'PKR' => '&#8360;',
  			'PLN' => '&#122;&#322;',
  			'PRB' => '&#x440;.',
  			'PYG' => '&#8370;',
  			'QAR' => '&#x631;.&#x642;',
  			'RMB' => '&yen;',
  			'RON' => 'lei',
  			'RSD' => '&#1088;&#1089;&#1076;',
  			'RUB' => '&#8381;',
  			'RWF' => 'Fr',
  			'SAR' => '&#x631;.&#x633;',
  			'SBD' => '&#36;',
  			'SCR' => '&#x20a8;',
  			'SDG' => '&#x62c;.&#x633;.',
  			'SEK' => '&#107;&#114;',
  			'SGD' => '&#36;',
  			'SHP' => '&pound;',
  			'SLL' => 'Le',
  			'SOS' => 'Sh',
  			'SRD' => '&#36;',
  			'SSP' => '&pound;',
  			'STN' => 'Db',
  			'SYP' => '&#x644;.&#x633;',
  			'SZL' => 'L',
  			'THB' => '&#3647;',
  			'TJS' => '&#x405;&#x41c;',
  			'TMT' => 'm',
  			'TND' => '&#x62f;.&#x62a;',
  			'TOP' => 'T&#36;',
  			'TRY' => '&#8378;',
  			'TTD' => '&#36;',
  			'TWD' => '&#78;&#84;&#36;',
  			'TZS' => 'Sh',
  			'UAH' => '&#8372;',
  			'UGX' => 'UGX',
  			'USD' => '&#36;',
  			'UYU' => '&#36;',
  			'UZS' => 'UZS',
  			'VEF' => 'Bs F',
  			'VES' => 'Bs.S',
  			'VND' => '&#8363;',
  			'VUV' => 'Vt',
  			'WST' => 'T',
  			'XAF' => 'CFA',
  			'XCD' => '&#36;',
  			'XOF' => 'CFA',
  			'XPF' => 'Fr',
  			'YER' => '&#xfdfc;',
  			'ZAR' => '&#82;',
  			'ZMW' => 'ZK',
  		)
  	);
  	return $symbols;
  }
}
